==> react-pagination-basic-1.6.0.tgz: package/lib/sui-pagination-item.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import PropTypes from 'prop-types';
import React from 'react';
import cx from 'classnames';
var baseClass = 'sui-PaginationBasic';
var PAGE_NUMBER_HOLDER = '%{pageNumber}';
export default function PaginationItem(_ref) {
  var _cx;

  var pageNumber = _ref.pageNumber,
      patternUrl = _ref.patternUrl,
      props = _objectWithoutPropertiesLoose(_ref, ["pageNumber", "patternUrl"]);

  var getText = function getText() {
    return React.createElement("span", {
      className: baseClass + "-text"
    }, props.pageText);
  };

  var onClick = function onClick(e) {
    return props.handlePaginate(pageNumber, e);
  };

  var itemBaseClass = baseClass + "-item";
  var classNames = cx(itemBaseClass, (_cx = {}, _cx[itemBaseClass + "--control"] = props.isControl, _cx[itemBaseClass + "--selected"] = props.isCurrent, _cx));
  return React.createElement("li", {
    className: classNames
  }, props.isCurrent ? getText() : props.factoryLink({
    onClick: onClick,
    className: baseClass + "-link",
    destinationURL: props.createUrl({
      pageNumber: pageNumber,
      patternUrl: patternUrl
    }),
    pageText: props.pageText
  }));
}
PaginationItem.defaultProps = {
  createUrl: function createUrl(_ref2) {
    var pageNumber = _ref2.pageNumber,
        patternUrl = _ref2.patternUrl;
    return patternUrl.replace(PAGE_NUMBER_HOLDER, pageNumber);
  },
  isCurrent: false,
  factoryLink: function factoryLink(_ref3) {
    var className = _ref3.className,
        destinationURL = _ref3.destinationURL,
        onClick = _ref3.onClick,
        pageText = _ref3.pageText;
    // eslint-disable-line
    var linkProps = {
      className: className,
      onClick: onClick
    };
    return React.createElement("a", Object.assign({}, linkProps, {
      href: destinationURL
    }), pageText);
  },
  patternUrl: '#'
};

==> react-pagination-basic-1.8.0.tgz: package/lib/sui-pagination-item.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import cx from 'classnames';
var baseClass = 'sui-PaginationBasic';
var PAGE_NUMBER_HOLDER = '%{pageNumber}';
export default function PaginationItem(_ref) {
  var _cx;

  var pageNumber = _ref.pageNumber,
      patternUrl = _ref.patternUrl,
      props = _objectWithoutPropertiesLoose(_ref, ["pageNumber", "patternUrl"]);

  var getText = function getText() {
    return /*#__PURE__*/_jsx("span", {
      className: baseClass + "-text",
      children: props.pageText
    });
  };

  var onClick = function onClick(e) {
    return props.handlePaginate(pageNumber, e);
  };

  var itemBaseClass = baseClass + "-item";
  var classNames = cx(itemBaseClass, (_cx = {}, _cx[itemBaseClass + "--control"] = props.isControl, _cx[itemBaseClass + "--selected"] = props.isCurrent, _cx));
  return /*#__PURE__*/_jsx("li", {
    className: classNames,
    children: props.isCurrent ? getText() : props.factoryLink({
      onClick: onClick,
      className: baseClass + "-link",
      destinationURL: props.createUrl({
        pageNumber: pageNumber,
        patternUrl: patternUrl
      }),
      pageText: props.pageText
    })
  });
}
PaginationItem.defaultProps = {
  createUrl: function createUrl(_ref2) {
    var pageNumber = _ref2.pageNumber,
        patternUrl = _ref2.patternUrl;
    return patternUrl.replace(PAGE_NUMBER_HOLDER, pageNumber);
  },
  isCurrent: false,
  factoryLink: function factoryLink(_ref3) {
    var className = _ref3.className,
        destinationURL = _ref3.destinationURL,
        onClick = _ref3.onClick,
        pageText = _ref3.pageText;
    // eslint-disable-line
    var linkProps = {
      className: className,
      onClick: onClick
    };
    return /*#__PURE__*/_jsx("a", _extends({}, linkProps, {
      href: destinationURL,
      children: pageText
    }));
  },
  patternUrl: '#'
};
